# Skynet Python SDK

An SDK for integrating Skynet into Python applications.

## Instructions

We recommend running your Python application using [pipenv](https://pipenv-searchable.readthedocs.io/basics.html). You can use `siaskynet` by installing it with `pip`, adding it to your project's `Pipfile`, or by cloning this repository.

## Documentation

For documentation complete with examples, please see [the Skynet SDK docs](https://nebulouslabs.github.io/skynet-docs/?python#introduction).

## Contributing

To run lints and tests on `python-skynet`, first run `make install` to install dependencies and then `make lint` or `make test`.
